#version 330

uniform sampler2D scene;
uniform sampler2D highlight;

uniform float exposure = 1.f;
uniform float sceneFactor = 0.f;
uniform float bloomFactor = 0.f;

layout (location = 0) out vec4 outputF;

//----------------------------------------------------------------
// TODO:
// 1) Load a texel from the rendered scene and scale it by sceneFactor.
// 2) Load a texel from the highlight scene and scale it by bloomFactor.
// 3) Sum the two texels together.
// 4) Use exposure to compute the tonemapped color.
//----------------------------------------------------------------
 
void main()
{
	// Combine the color of the rendered scene with the blurred highlight
	vec4 color = vec4(0.f);
	color += texelFetch(scene, ivec2(gl_FragCoord.xy), 0) * sceneFactor;
	color += texelFetch(highlight, ivec2(gl_FragCoord.xy), 0) * bloomFactor;

	// Tonemapping
	outputF = vec4(vec3(1.f) - exp2(-color.rgb * exposure), 1.f);
}