#version 330

// Material properties
uniform float bloom_thresh_min = 0.9f;
uniform float bloom_thresh_max = 1.2f;

struct materialProps
{
	vec4 diffuse;
	vec4 ambient;
	vec4 specular;
	vec4 emissive;
	float shininess;
	int texCount;
};

layout (std140) uniform Materials
{
	materialProps material[32];
};

in Data
{
	vec3 normal;	// camera space
	vec3 eye;		// camera space
	vec3 lightDir;	// camera space
	flat int matIdx;
} DataIn;

layout (location = 0) out vec4 color;
layout (location = 1) out vec4 highlight;

//----------------------------------------------------------------
// TODO:
// 1) Use material properties based on the material index to compute Blinn-Phong shading.
// 2) Save the shaded color to the first output, and the highlight color to the second output.
//----------------------------------------------------------------

void main()
{
	// Compute Blinn-Phong shading
	vec4 spec = vec4(0.f);

	vec3 n = normalize(DataIn.normal);
	vec3 l = normalize(DataIn.lightDir);
	vec3 e = normalize(DataIn.eye);

	float intensity = max(dot(n, l), 0.f);

	if(intensity > 0.f)
	{
		vec3 h = normalize(l + e);
		float intSpec = max(dot(h, n), 0.f);
		spec = material[DataIn.matIdx].specular * pow(intSpec, material[DataIn.matIdx].shininess);
	}
	
	vec4 col = material[DataIn.matIdx].ambient + intensity * material[DataIn.matIdx].diffuse + spec;
	// Write final color to the framebuffer
	color = col;

	// Calculate luminance
	float Y = dot(vec3(col), vec3(0.299f, 0.587f, 0.144f));
	// Threshold color based on its luminance and write the highlighs to the second output
	col = col * 4.f * smoothstep(bloom_thresh_min, bloom_thresh_max, Y);
	highlight = vec4(col.xyz, 1.f);
}