#version 330

layout (std140) uniform Matrices
{
	mat4 m_model[32];
	mat4 m_view;
	mat4 m_proj;
};

layout (std140) uniform Lights
{
	vec4 l_pos;		// camera space
};

in vec4 position;	// local space
in vec3 normal;		// local space

out Data
{
	vec3 normal;
	vec3 eye;
	vec3 lightDir;
	flat int matIdx;
} DataOut;

//----------------------------------------------------------------
// TODO:
// 1) Transform the vertices based on their gl_InstanceID.
// 1) Pass the gl_InstanceID for later use as material index.
//----------------------------------------------------------------

void main()
{
	mat4 viewModel = m_view * m_model[gl_InstanceID];

	// Compute the vertex position in camera space
	vec4 pos = viewModel * position;

	// Pass the normal, light and eye in camera space to the fragment shader
	DataOut.normal = normalize(mat3(viewModel) * normal);
	DataOut.eye = vec3(-pos);
	DataOut.lightDir = vec3(l_pos - pos);
	// Pass the material index
	DataOut.matIdx = gl_InstanceID;

	gl_Position = m_proj * pos;	
}